==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/CorruptSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CorruptSpecFluent<A extends CorruptSpecFluent<A>> extends BaseFluent<A>{
  public CorruptSpecFluent() {
  }
  
  public CorruptSpecFluent(CorruptSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String corrupt;
  
  protected void copyInstance(CorruptSpec instance) {
    instance = (instance != null ? instance : new CorruptSpec());
  
    if (instance != null) {
        this.withCorrelation(instance.getCorrelation());
        this.withCorrupt(instance.getCorrupt());
        this.withCorrelation(instance.getCorrelation());
        this.withCorrupt(instance.getCorrupt());
      }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getCorrupt() {
    return this.corrupt;
  }
  
  public A withCorrupt(String corrupt) {
    this.corrupt=corrupt; return (A) this;
  }
  
  public boolean hasCorrupt() {
    return this.corrupt != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CorruptSpecFluent that = (CorruptSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
  
    if (!java.util.Objects.equals(corrupt, that.corrupt)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  corrupt,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (corrupt != null) { sb.append("corrupt:"); sb.append(corrupt); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/CorruptSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CorruptSpecFluent<A extends CorruptSpecFluent<A>> extends BaseFluent<A>{
  public CorruptSpecFluent() {
  }
  
  public CorruptSpecFluent(CorruptSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String corrupt;
  
  protected void copyInstance(CorruptSpec instance) {
    instance = (instance != null ? instance : new CorruptSpec());
    if (instance != null) {
          this.withCorrelation(instance.getCorrelation());
          this.withCorrupt(instance.getCorrupt());
          this.withCorrelation(instance.getCorrelation());
          this.withCorrupt(instance.getCorrupt());
        }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation = correlation;
    return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getCorrupt() {
    return this.corrupt;
  }
  
  public A withCorrupt(String corrupt) {
    this.corrupt = corrupt;
    return (A) this;
  }
  
  public boolean hasCorrupt() {
    return this.corrupt != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CorruptSpecFluent that = (CorruptSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
    if (!java.util.Objects.equals(corrupt, that.corrupt)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  corrupt,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (corrupt != null) { sb.append("corrupt:"); sb.append(corrupt); }
    sb.append("}");
    return sb.toString();
  }
  

}
